service

package
v0.8.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 15, 2018 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AuthenticationComplete

func AuthenticationComplete()

AuthenticationComplete flags that the Hub login process is complete

func GetHub

func GetHub() *homehub.Hub

GetHub gets the stored instance of Hub

func IsLoggedIn

func IsLoggedIn() bool

IsLoggedIn returns whether a user is logged into the Hub

func NewHub

func NewHub(hubURL string, userName string, password string) *homehub.Hub

NewHub creates a new Hub

func StringIsEmpty

func StringIsEmpty(s string) bool

StringIsEmpty checks to see if a string is empty

Types

This section is empty.

Jump to