Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AuthenticationComplete ¶
func AuthenticationComplete()
AuthenticationComplete flags that the Hub login process is complete
func StringIsEmpty ¶
StringIsEmpty checks to see if a string is empty
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.